@@ -13,7 +13,7 @@ from ..component import Component, DerivedComponent, CategoricalComponent, DateT
 from ..component_id import ComponentID
 from ..component_link import ComponentLink, CoordinateComponentLink, BinaryComponentLink
 from ..coordinates import Coordinates, IdentityCoordinates
-from ..data import Data, pixel_label, BaseCartesianData
+from ..data import Data, pixel_label
 from ..link_helpers import LinkSame
 from ..data_collection import DataCollection
 from ..exceptions import IncompatibleAttribute
@@ -1127,39 +1127,3 @@ def test_compute_histogram_dask_mixed():
 
     result = data.compute_histogram([data.id['y'], data.id['x']], range=[[-0.5, 11.25], [-0.5, 11.25]], bins=[2, 3], subset_state=data.id['x'] > 4.5)
     assert_allclose(result, [[0, 1, 0], [0, 2, 2]])
-
-
-def test_base_cartesian_data_coords():
-
-    # Make sure that world_component_ids works in both the case where
-    # coords is not defined and when it is defined.
-
-    class CustomData(BaseCartesianData):
-
-        def get_kind(self):
-            pass
-
-        def compute_histogram(self):
-            pass
-
-        def compute_statistic(self):
-            pass
-
-        def get_mask(self):
-            pass
-
-        @property
-        def shape(self):
-            return (1, 4, 3)
-
-        @property
-        def main_components(self):
-            return []
-
-    data1 = CustomData()
-    assert len(data1.pixel_component_ids) == 3
-    assert len(data1.world_component_ids) == 0
-
-    data2 = CustomData(coords=IdentityCoordinates(n_dim=3))
-    assert len(data2.pixel_component_ids) == 3
-    assert len(data2.world_component_ids) == 3
