@@ -110,6 +110,7 @@ class ColoredLineCollection(LineCollection):
             data_new = np.zeros((len(data) - 1) * 2)
             data_new[::2] = data[:-1]
             data_new[1::2] = data[1:]
+            self.set_color(None)
             set_mpl_artist_cmap(self, data_new, **kwargs)
         else:
             if isinstance(color, np.ndarray):
@@ -315,13 +316,13 @@ class ScatterLayerArtist(MatplotlibLayerArtist):
 
             if self.state.xerr_visible and self.state.xerr_att is not None:
                 xerr = ensure_numerical(self.layer[self.state.xerr_att].ravel()).copy()
-                keep &= ~np.isnan(xerr)
+                keep &= ~np.isnan(xerr) & (xerr >= 0.)
             else:
                 xerr = None
 
             if self.state.yerr_visible and self.state.yerr_att is not None:
                 yerr = ensure_numerical(self.layer[self.state.yerr_att].ravel()).copy()
-                keep &= ~np.isnan(yerr)
+                keep &= ~np.isnan(yerr) & (yerr >= 0.)
             else:
                 yerr = None
 
